@@ -16,7 +16,7 @@
  */
 
 #include "remotelistmodel.h"
-#include "../base/definitions.h"
+#include "definitions.h"
 #include <QDir>
 
 RemoteListModel::RemoteListModel(QObject *parent) :
